{% load cms_tags i18n %}
{% load url from future %}

<div class="list-group">
    {% for question in object_list %}
        <a href="{{ question.get_absolute_url }}" class="list-group-item">
            {% render_model question "title" %}
        </a>
    {% empty %}
        <p class="list-group-item">{% trans "No entry found." %}</p>
    {% endfor %}
</div>
