{% extends "aldryn_faq/two_column.html" %}
{% load i18n cms_tags %}

{% block faq_sidebar %}
    {% render_placeholder view.config.placeholder_faq_sidebar_top %}
    {% include "aldryn_faq/plugins/category_list.html" with categories=category_list %}
    {% render_placeholder view.config.placeholder_faq_sidebar_bottom %}
{% endblock %}

{% block faq_content %}
    {% render_placeholder view.config.placeholder_faq_content %}
{% endblock %}
